==> plantuml-libs-7.1.0.tgz: package/distribution/fontawesome-6/Regular/FaceGrinTongueSquint.md <==
# FaceGrinTongueSquint


```text
fontawesome-6/Regular/FaceGrinTongueSquint
```

```text
include('fontawesome-6/Regular/FaceGrinTongueSquint')
```



| Illustration | FaceGrinTongueSquint |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Regular/FaceGrinTongueSquint.png) | ![illustration for FaceGrinTongueSquint](../../fontawesome-6/Regular/FaceGrinTongueSquint.Local.png) |




## FaceGrinTongueSquint

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element FaceGrinTongueSquint
include('fontawesome-6/Regular/FaceGrinTongueSquint')

' renders the element
FaceGrinTongueSquint('FaceGrinTongueSquint', 'Face Grin Tongue Squint', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element FaceGrinTongueSquint
include('fontawesome-6/Regular/FaceGrinTongueSquint')

' renders the element
FaceGrinTongueSquint('FaceGrinTongueSquint', 'Face Grin Tongue Squint', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.2.0.tgz: package/distribution/fontawesome-6/Regular/FaceGrinTongueSquint.md <==
# FaceGrinTongueSquint


```text
fontawesome-6/Regular/FaceGrinTongueSquint
```

```text
include('fontawesome-6/Regular/FaceGrinTongueSquint')
```



| Illustration | FaceGrinTongueSquint |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Regular/FaceGrinTongueSquint.png) | ![illustration for FaceGrinTongueSquint](../../fontawesome-6/Regular/FaceGrinTongueSquint.Local.png) |




## FaceGrinTongueSquint

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element FaceGrinTongueSquint
include('fontawesome-6/Regular/FaceGrinTongueSquint')

' renders the element
FaceGrinTongueSquint('FaceGrinTongueSquint', 'Face Grin Tongue Squint', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element FaceGrinTongueSquint
include('fontawesome-6/Regular/FaceGrinTongueSquint')

' renders the element
FaceGrinTongueSquint('FaceGrinTongueSquint', 'Face Grin Tongue Squint', 'an optional tech label', 'an optional description')
@enduml
```
